'''
SHA3-256(/Volumes/thder_data/home_mike/svnwork/current/snakeland_guru/head/public/script/snakeland.py)= 829dd6125b28f179fb3153bce32e1eacd6596cded32a2c8b60d2ee06c7f116b9
SHA3-256(/Volumes/thder_data/home_mike/svnwork/current/snakeland_guru/head/public/pypi/snakeland/__init__.py)= bf14969e85ba8748cb41c2c45e5f626ea2c933b22ffdccfffad1b1ee7b6f1984
SHA3-256(/Volumes/thder_data/home_mike/svnwork/current/snakeland_guru/head/public/pypi/snakeland/__main__.py)= 31469ad31ec71048ffef4671fcb21d3e0e93961f5e37cf656a1de643d69a7027
'''
